Structural data markers — Effect.ts Data–style equality and hashing.
EffectData is implemented automatically for any type that already implements
PartialEq, Eq, and Hash. Use the EffectData
derive macro to generate those impls field-wise for your own structs and enums.
DataStruct and DataTuple are newtype wrappers for values you want to treat as
opaque “data” values in APIs. DataError combines std::error::Error with
EffectData for error types used in maps and sets.
Structs
- Data
Struct - Newtype wrapping a struct (or any value type) that is compared and hashed by its inner value.
- Data
Tuple - Newtype wrapping a tuple (or tuple-like product) for structural equality and hashing.
Traits
- Data
Error - Errors that are also
EffectData(structurally comparable / hashable). - Effect
Data - Marker for Effect-style structural equality and hashing (
PartialEq+Eq+Hash).